==> php81-nextcloud-26.0.5.tgz: share/nextcloud/apps/theming/l10n/sc.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Custu nùmene est tropu longu",
    "The given web address is too long" : "Custu indiritzu web est tropu longu",
    "The given web address is not a valid URL" : "S'indiritzu web dadu no est un'URL bàlidu",
    "The given legal notice address is too long" : "S'indiritzu de s'avisu legale dadu est tropu longu",
    "The given legal notice address is not a valid URL" : "S'indiritzu de is notas legales dadu no est un'URL bàlidu",
    "The given privacy policy address is too long" : "S'indiritzu de su critèriu de riservadesa dadu est tropu longu",
    "The given privacy policy address is not a valid URL" : "S'indiritzu de su critèriu de riservadesa dadu no est un'URL bàlidu",
    "The given slogan is too long" : "Custu slogan est tropu longu",
    "The given color is invalid" : "Custu colore no est bàlidu",
    "Saved" : "Sarvadu",
    "The file was uploaded" : "S'archìviu est istadu carrigadu",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu passat sa diretiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "S'archìviu carrigadu passat sa diretiva MAX_FILE_SIZE ispetzificada in su mòdulu HTML",
    "The file was only partially uploaded" : "S'archìviu est istadu carrigadu isceti in parte",
    "No file was uploaded" : "Non s'est carrigadu perunu archìviu",
    "Missing a temporary folder" : "Mancat una cartella temporànea",
    "Could not write file to disk" : "Non faghet a iscrìere s'archìviu in su discu",
    "A PHP extension stopped the file upload" : "Un'estensione PHP at firmadu su carrigamentu de s'archìviu",
    "No file uploaded" : "Perunu archìviu carrigadu",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ses giai impreende unu tema personalizadu. Is impostatziones de s'aplicatzione de is temas si diant pòdere subraiscrìere.",
    "Theming" : "Tema",
    "Dark theme" : "Tema iscuru ",
    "Enable dark theme" : "Ativa su tema iscuru ",
    "Dyslexia font" : "Font pro dislessia",
    "Enable dyslexia font" : "Ativa su font pro dislessia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic est unu font lìberu pensadu pro illebiare unos cantos isbàllios comunes de leghidura causados dae sa dislessia.",
    "High contrast mode" : "Modalidade cuntrastu artu",
    "Enable high contrast mode" : "Ativa sa modalidade cuntrastu altu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Unu cuntrastu artu pro agiudare sa navigatzione tua. S'at a menguare sa calidade de visualizatzione, ma at a crèschere sa craresa.",
    "Legal notice" : "Avisu legale",
    "Privacy policy" : "Critèriu de riservadesa",
    "Adjust the Nextcloud theme" : "Modìfica su tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Sa gestione de is temas faghet chi sa personalizatzione de sa bista de s'istàntzia tua e de is clientes suportados siat prus fàtzile. Custu at a èssere visìbile pro totu is utentes.",
    "Advanced options" : "Sèberos avantzados",
    "Name" : "Nùmene",
    "Web link" : "Ligòngiu web",
    "a safe home for all your data" : "unu logu siguru pro totu is datos tuos",
    "Slogan" : "Slogan",
    "Color" : "Colore",
    "Logo" : "Logo",
    "Upload new logo" : "Càrriga logo nou",
    "Legal notice link" : "Ligòngiu avisu legale",
    "Privacy policy link" : "Ligòngiu critèrios de riservadesa",
    "Header logo" : "Logo de intestatzione",
    "Upload new header logo" : "Càrriga logo de intestatzione nou",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Càrriga favicon noa",
    "User settings" : "Impostatziones utente",
    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
    "Background" : "Isfundu",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "S'atzessu universale est de importu mannu pro nois. Sighimus is istandard de sa rete e chircamus de fàghere chi totu si potzat impreare chene cursore puru, e cun programmas de assistèntzia comente leghidores de ischermu. S'intentu nostru est de acumprire is inditos de is {guidelines}Lìinas ghia cuntenutos de rete{linkend} 2.1 a su livellu AA, cun su tema de cuntrastu artu a su livellu AAA.",
    "Change color" : "Càmbia colore",
    "Reset to default" : "Torra a is impostatziones predefinidas",
    "Upload" : "Càrriga",
    "Remove background image" : "Boga immàgine de fundu",
    "Loading preview…" : "Carrigamentu anteprima...",
    "Admin" : "Amministradore",
    "Name cannot be empty" : "Su nùmene non podet èssere isbòidu",
    "Pick from Files" : "Sèbera dae archìvios",
    "Custom color" : "Personaliza colore",
    "Plain background" : "Isfundu simpre",
    "Insert from {productName}" : "Inserta dae {productName}",
    "Open documentation" : "Aberi sa documentatzione",
    "https://…" : "https://…",
    "Upload new login background" : "Càrriga fundu de intrada nou",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa s'estensione Imagemagick de PHP cun suportu pro is immàgines SVG pro generare in automàticu favicon basadas subra de su logo carrigadu e su colore."
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-28.0.2.tgz: share/nextcloud/apps/theming/l10n/sc.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Custu nùmene est tropu longu",
    "The given web address is too long" : "Custu indiritzu web est tropu longu",
    "The given web address is not a valid URL" : "S'indiritzu web dadu no est un'URL bàlidu",
    "The given legal notice address is too long" : "S'indiritzu de s'avisu legale dadu est tropu longu",
    "The given legal notice address is not a valid URL" : "S'indiritzu de is notas legales dadu no est un'URL bàlidu",
    "The given privacy policy address is too long" : "S'indiritzu de su critèriu de riservadesa dadu est tropu longu",
    "The given privacy policy address is not a valid URL" : "S'indiritzu de su critèriu de riservadesa dadu no est un'URL bàlidu",
    "The given slogan is too long" : "Custu slogan est tropu longu",
    "The given color is invalid" : "Custu colore no est bàlidu",
    "Saved" : "Sarvadu",
    "The file was uploaded" : "S'archìviu est istadu carrigadu",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu passat sa diretiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "S'archìviu carrigadu passat sa diretiva MAX_FILE_SIZE ispetzificada in su mòdulu HTML",
    "The file was only partially uploaded" : "S'archìviu est istadu carrigadu isceti in parte",
    "No file was uploaded" : "Non s'est carrigadu perunu archìviu",
    "Missing a temporary folder" : "Mancat una cartella temporànea",
    "Could not write file to disk" : "Non faghet a iscrìere s'archìviu in su discu",
    "A PHP extension stopped the file upload" : "Un'estensione PHP at firmadu su carrigamentu de s'archìviu",
    "No file uploaded" : "Perunu archìviu carrigadu",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ses giai impreende unu tema personalizadu. Is impostatziones de s'aplicatzione de is temas si diant pòdere subraiscrìere.",
    "Theming" : "Tema",
    "Dark theme" : "Tema iscuru ",
    "Enable dark theme" : "Ativa su tema iscuru ",
    "Dyslexia font" : "Font pro dislessia",
    "Enable dyslexia font" : "Ativa su font pro dislessia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic est unu font lìberu pensadu pro illebiare unos cantos isbàllios comunes de leghidura causados dae sa dislessia.",
    "High contrast mode" : "Modalidade cuntrastu artu",
    "Enable high contrast mode" : "Ativa sa modalidade cuntrastu altu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Unu cuntrastu artu pro agiudare sa navigatzione tua. S'at a menguare sa calidade de visualizatzione, ma at a crèschere sa craresa.",
    "Legal notice" : "Avisu legale",
    "Privacy policy" : "Critèriu de riservadesa",
    "Adjust the Nextcloud theme" : "Modìfica su tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Sa gestione de is temas faghet chi sa personalizatzione de sa bista de s'istàntzia tua e de is clientes suportados siat prus fàtzile. Custu at a èssere visìbile pro totu is utentes.",
    "Advanced options" : "Sèberos avantzados",
    "Name" : "Nùmene",
    "Web link" : "Ligòngiu web",
    "a safe home for all your data" : "unu logu siguru pro totu is datos tuos",
    "Slogan" : "Slogan",
    "Color" : "Colore",
    "Logo" : "Logo",
    "Upload new logo" : "Càrriga logo nou",
    "Legal notice link" : "Ligòngiu avisu legale",
    "Privacy policy link" : "Ligòngiu critèrios de riservadesa",
    "Header logo" : "Logo de intestatzione",
    "Upload new header logo" : "Càrriga logo de intestatzione nou",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Càrriga favicon noa",
    "User settings" : "Impostatziones utente",
    "Background" : "Isfundu",
    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "S'atzessu universale est de importu mannu pro nois. Sighimus is istandard de sa rete e chircamus de fàghere chi totu si potzat impreare chene cursore puru, e cun programmas de assistèntzia comente leghidores de ischermu. S'intentu nostru est de acumprire is inditos de is {guidelines}Lìinas ghia cuntenutos de rete{linkend} 2.1 a su livellu AA, cun su tema de cuntrastu artu a su livellu AAA.",
    "Move up" : "Tràmuda fache a susu",
    "Move down" : "Tràmuda fache a bàsciu",
    "Change color" : "Càmbia colore",
    "Reset to default" : "Torra a is impostatziones predefinidas",
    "Upload" : "Càrriga",
    "Remove background image" : "Boga immàgine de fundu"
},
"nplurals=2; plural=(n != 1);");
